summaryrefslogtreecommitdiffhomepage
path: root/src/Xmobar/Config/Types.hs
diff options
context:
space:
mode:
Diffstat (limited to 'src/Xmobar/Config/Types.hs')
-rw-r--r--src/Xmobar/Config/Types.hs6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/Xmobar/Config/Types.hs b/src/Xmobar/Config/Types.hs
index 6ea012f..5f19528 100644
--- a/src/Xmobar/Config/Types.hs
+++ b/src/Xmobar/Config/Types.hs
@@ -16,7 +16,7 @@ module Xmobar.Config.Types
( -- * Configuration
-- $config
Config (..)
- , XPosition (..), Align (..), Border(..)
+ , XPosition (..), Align (..), Border (..), TextColorFormat (..)
, SignalChan (..)
) where
@@ -37,7 +37,7 @@ data Config =
, fgColor :: String -- ^ Default font color
, position :: XPosition -- ^ Top Bottom or Static
, textOutput :: Bool -- ^ Write data to stdout instead of X
- , ansiColors :: Bool -- ^ Use ANSI color escapes for stdout
+ , textOutputColors :: TextColorFormat -- ^ Which color format to use for stdout: Ansi or Pango
, textOffset :: Int -- ^ Offset from top of window for text
, textOffsets :: [Int] -- ^ List of offsets for additionalFonts
, iconOffset :: Int -- ^ Offset from top of window for icons
@@ -98,6 +98,8 @@ data Border = NoBorder
| FullBM Int
deriving ( Read, Show, Eq )
+data TextColorFormat = NoColors | Ansi | Pango deriving ( Read, Show, Eq )
+
newtype SignalChan = SignalChan { unSignalChan :: Maybe (STM.TMVar SignalType) }
instance Read SignalChan where